using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.Hosting;
using Serilog;
using Serilog.Events;

namespace AspNetCoreSerilogExample
{
    public static class Program
    {
        public static void Main(string[] args)
        {
            Log.Logger = new LoggerConfiguration()
                // минимальный уровень логирования - Debug
                .MinimumLevel.Debug()
                // Скрываем логи с уровнем ниже Warning для пространства имен Microsoft.AspNetCore*
                .MinimumLevel.Override("Microsoft.AspNetCore", LogEventLevel.Warning)
                // расширяем логируемые данные с помощью LogContext
                .Enrich.FromLogContext()
                // пишем логи в консоль с использованием шаблона
                .WriteTo.Console(outputTemplate: "[{Timestamp:HH:mm:ss} {Level:u3} {SourceContext}] {Message:lj}{NewLine}{Exception}")
                .CreateLogger();
            
            CreateHostBuilder(args).Build().Run();
        }

        private static IHostBuilder CreateHostBuilder(string[] args) =>
            Host.CreateDefaultBuilder(args)
                .UseSerilog() // подключаем Serilog как пройдера логирования по умолчанию
                .ConfigureWebHostDefaults(webBuilder => { webBuilder.UseStartup<Startup>(); });
    }
}